Citing ytree
============

If you use ytree in your work, please cite the following:

Britton Smith, & Meagan Lang. (2018, February 16). 
ytree: merger-tree toolkit. Zenodo.
http://doi.org/10.5281/zenodo.1174374

For BibTeX users:

::

  @misc{britton_smith_2018_1174374,
    author       = {Britton Smith and
                    Meagan Lang},
    title        = {ytree: merger-tree toolkit},
    month        = feb,
    year         = 2018,
    doi          = {10.5281/zenodo.1174374},
    url          = {https://doi.org/10.5281/zenodo.1174374}
  }

If possible, please also add a footnote pointing to
http://ytree.readthedocs.io.
